netapp_ontap.models.svm_cifs_service API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.svm_cifs_service`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SvmCifsServiceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SvmCifsService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ad_domain GET POST PATCH`

    The ad_domain field of the svm_cifs_service.

  `enabled GET POST PATCH`

    Specifies whether or not the CIFS service is administratively enabled.

  `links GET`

    The links field of the svm_cifs_service.

  `name GET POST PATCH`

    The NetBIOS name of the CIFS server.

    Example: CIFS1